pub enum WorkspaceLocation {
Constant(PathBuf),
FromEnvVar {
env: String,
relpath: PathBuf,
},
}Variants
Constant(PathBuf)
FromEnvVar
Workspace directory specified by dereferencing the value of the environment variable and appending the relative path to it.
Example: WorkspaceLocation::FromEnvVar{ env:"WORKSPACE_DIR", relpath: PathBuf::from("github/torchtitan) }
points to $WORKSPACE_DIR/github/torchtitan.
Implementations